/*
* UltraDefrag reports sorting engine.
* Copyright (C) 2018 Green Gate Systems, LLC.
*
* ALL RIGHTS RESERVED. YOU MAY NOT DISTRIBUTE OR MODIFY THIS SOFTWARE.
*
* THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EITHER
* EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK
* AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD
* THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY
* SERVICING, REPAIR OR CORRECTION.
*
* IN NO EVENT WILL THE AUTHORS AND COPYRIGHT HOLDERS BE LIABLE TO YOU
* FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL
* DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING
* BUT NOT LIMITED TO LOSS OF DATA OR A FAILURE OF THE PROGRAM TO OPERATE
* WITH ANY OTHER PROGRAMS).
*/

/*
* Interface:
* 1. init_sorting_engine()
* 2. sort_items(criteria), where criteria is 
*  {"fragments" | "size" | "name" | "comment" | "status"}
*/

/* global variables */
var
 // 0 - descending, 1 - ascending
 fragments_order = 1,
 size_order = 0,
 name_order = 0,
 comment_order = 1,
 status_order = 1,
 msie_browser = false;

function init_sorting_engine()
{
 if(window.navigator.appName === "Microsoft Internet Explorer")
  msie_browser = true;
}

function sort_by_fragments(a,b)
{
 var
  fa = parseInt(a.getElementsByTagName("td")[0].innerHTML),
  fb = parseInt(b.getElementsByTagName("td")[0].innerHTML);
 return (fragments_order) ? (fa - fb) : (fb - fa);
}

function sort_by_size(a,b)
{
 var
  fa = parseInt(a.getElementsByTagName("td")[1].id),
  fb = parseInt(b.getElementsByTagName("td")[1].id);
 return (size_order) ? (fa - fb) : (fb - fa);
}

function sort_by_name(a,b)
{
 var
  na = a.getElementsByTagName("td")[2].innerHTML.toLowerCase(),
  nb = b.getElementsByTagName("td")[2].innerHTML.toLowerCase(),
  result = (na > nb) ? 1 : (na === nb) ? 0 : -1;
 return (name_order) ? -result : result;
}

function sort_by_comment(a,b)
{
 var
  ca = a.getElementsByTagName("td")[3].innerHTML.toLowerCase(),
  cb = b.getElementsByTagName("td")[3].innerHTML.toLowerCase(),
  result = (ca > cb) ? 1 : (ca === cb) ? 0 : -1;
 return (comment_order) ? -result : result;
}

function sort_by_status(a,b)
{
 var
  ca = a.getElementsByTagName("td")[4].innerHTML.toLowerCase(),
  cb = b.getElementsByTagName("td")[4].innerHTML.toLowerCase(),
  result = (ca > cb) ? 1 : (ca === cb) ? 0 : -1;
 return (status_order) ? -result : result;
}

function sort_items(criteria)
{
 var i, a = [], rows = "",
  table = document.getElementById("main_table"),
  items = table.getElementsByTagName("tr"),
  header = "<tr>" + items[0].innerHTML + "</tr>\n";

 // convert the collection to an array
 for(i = 1; i < items.length; i++)
  a[i-1] = items[i];

 // sort items
 if(criteria === 'fragments'){
  a.sort(sort_by_fragments);
  fragments_order = fragments_order ? 0 : 1;
 } else if(criteria === 'size'){
  a.sort(sort_by_size);
  size_order = size_order ? 0 : 1;
 } else if(criteria === 'name'){
  a.sort(sort_by_name);
  name_order = name_order ? 0 : 1;
 } else if(criteria === 'comment'){
  a.sort(sort_by_comment);
  comment_order = comment_order ? 0 : 1;
 } else if(criteria === 'status'){
  a.sort(sort_by_status);
  status_order = status_order ? 0 : 1;
 } else
  return; // invalid criteria

 // loop through the array of sorted items
 for(i = 0; i < a.length; i++)
  rows += "<tr>" + a[i].innerHTML + "</tr>\n";

 // replace the old contents with the new sorted one
 if(!msie_browser){
  table.innerHTML = header + rows;
 } else {
  // On Internet Explorer the table.innerHTML is read only,
  // so we need to replace the whole table ...
  document.getElementById("for_msie").innerHTML =
   "<table id=\"main_table\">" + header + rows + "</table>";
 }
}
